@@ -169,7 +169,7 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
             ClinicalQualityMeasure.CHANGE_PATIENT,
         ]
 
-        show_in_chart = False
+        show_in_chart = True
         show_in_population = False
 
     MINIMUM_AGE = 18
