@@ -23,19 +23,19 @@ class TestCcp002v1(SDKBaseTest):
 
     def test_description(self):
         expected = 'All patients with 65+ with chronic conditions to be reached.'
-        self.assertEqual(expected, Ccp002v1.description)
+        self.assertEqual(expected, Ccp002v1._meta.description)
 
     def test_information(self):
         expected = ('https://canvas-medical.zendesk.com/hc/en-us/articles/360059327893')
-        self.assertEqual(expected, Ccp002v1.information)
+        self.assertEqual(expected, Ccp002v1._meta.information)
 
     def test_change_types(self):
-        result = Ccp002v1.compute_on_change_types
+        result = Ccp002v1._meta.compute_on_change_types
         expected = ['condition', 'interview', 'patient']
         self.assertEqual(expected, result)
 
-    def test_revision(self):
-        self.assertEqual('2020-03-24v1', Ccp002v1.revision())
+    def test_version(self):
+        self.assertTrue(hasattr(Ccp002v1._meta, 'version'))
 
     def test_date_of_first_questionnaire(self):
         start = arrow.get('2019-03-24 13:24:56')
@@ -154,7 +154,7 @@ class TestCcp002v1(SDKBaseTest):
         ], result)
 
     def test_in_initial_population(self):
-        with patch('protocols.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now') as now:
+        with patch('canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now') as now:
             now.return_value = arrow.get('2020-03-22 13:24:56')
 
             start = arrow.get('2019-03-22 13:24:56')
@@ -184,7 +184,7 @@ class TestCcp002v1(SDKBaseTest):
             self.assertFalse(result)
 
     def test_in_denominator(self):
-        with patch('protocols.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now') as now:
+        with patch('canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now') as now:
             now.return_value = arrow.get('2020-03-22 13:24:56')
 
             start = arrow.get('2019-03-22 13:24:56')
@@ -255,14 +255,14 @@ class TestCcp002v1(SDKBaseTest):
         self.assertTrue(result)
 
     @patch(
-        'protocols.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.high_risk_conditions',
+        'canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.high_risk_conditions',
         new_callable=PropertyMock)
     @patch(
-        'protocols.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.date_of_first_questionnaire',
+        'canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.date_of_first_questionnaire',
         new_callable=PropertyMock)
-    @patch('protocols.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.in_numerator')
-    @patch('protocols.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.in_denominator')
-    @patch('protocols.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now')
+    @patch('canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.in_numerator')
+    @patch('canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.Ccp002v1.in_denominator')
+    @patch('canvas_workflow_kit.builtin_cqms.ccp002v1_high_risk_outreach.arrow.now')
     def test_compute_results(self, now, in_denominator, in_numerator, date_of_first_questionnaire,
                              high_risk_conditions):
         now.return_value = arrow.get('2020-03-22 13:24:56')
