@@ -23,20 +23,20 @@ class ClinicalQualityMeasure122v6Test(SDKBaseTest):
         expected = (
             'Patients 18-75 years of age with diabetes who have either a hemoglobin A1c > 9.0% '
             'or no hemoglobin A1c within the last year.')
-        self.assertEqual(expected, ClinicalQualityMeasure122v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure122v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms122v6'
-        self.assertEqual(expected, ClinicalQualityMeasure122v6.information)
+        self.assertEqual(expected, ClinicalQualityMeasure122v6._meta.information)
 
     def test_enabled(self):
         self.assertTrue(ClinicalQualityMeasure122v6.enabled())
 
-    def test_revision(self):
-        self.assertEqual('2019-02-12v1', ClinicalQualityMeasure122v6.revision())
+        def test_version(self):
+            self.assertTrue(hasattr(ClinicalQualityMeasure122v6._meta, 'version'))
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure122v6.compute_on_change_types
+        result = ClinicalQualityMeasure122v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
