@@ -16,20 +16,20 @@ class TestClinicalQualityMeasure125v6(SDKBaseTest):
     def test_description(self):
         expected = ('Women 50-74 years of age who have not had a mammogram to screen for '
                     'breast cancer within the last 27 months.')
-        self.assertEqual(expected, ClinicalQualityMeasure125v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure125v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms125v6'
-        self.assertEqual(expected, ClinicalQualityMeasure125v6.information)
+        self.assertEqual(expected, ClinicalQualityMeasure125v6._meta.information)
 
     def test_enabled(self):
         self.assertTrue(ClinicalQualityMeasure125v6.enabled())
 
-    def test_revision(self):
-        self.assertEqual('2002-02-12v1', ClinicalQualityMeasure125v6.revision())
+    def test_version(self):
+        self.assertTrue(hasattr(ClinicalQualityMeasure125v6._meta, 'version'))
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure125v6.compute_on_change_types
+        result = ClinicalQualityMeasure125v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
