@@ -23,20 +23,17 @@ class ClinicalQualityMeasure130v6Test(SDKBaseTest):
     def test_description(self):
         expected = ('Adults 50-75 years of age who have not had appropriate '
                     'screening for colorectal cancer.')
-        self.assertEqual(expected, ClinicalQualityMeasure130v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure130v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms130v6'
-        self.assertEqual(expected, ClinicalQualityMeasure130v6.information)
+        self.assertEqual(expected, ClinicalQualityMeasure130v6._meta.information)
 
     def test_enabled(self):
         self.assertTrue(ClinicalQualityMeasure130v6.enabled())
 
-    def test_revision(self):
-        self.assertEqual('2020-02-24v1', ClinicalQualityMeasure130v6.revision())
-
     def test_change_types(self):
-        result = ClinicalQualityMeasure130v6.compute_on_change_types
+        result = ClinicalQualityMeasure130v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
