@@ -19,17 +19,17 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
     def test_description(self):
         expected = ('Patients 18-75 years of age with diabetes who have not had a retinal or '
                     'dilated eye exam by an eye care professional.')
-        self.assertEqual(expected, ClinicalQualityMeasure131v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure131v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms131v6'
-        self.assertEqual(expected, ClinicalQualityMeasure131v6.information)
+        self.assertEqual(expected, ClinicalQualityMeasure131v6._meta.information)
 
-    def test_revision(self):
-        self.assertEqual('2019-08-02v1', ClinicalQualityMeasure131v6.revision())
+    def test_version(self):
+        self.assertTrue(hasattr(ClinicalQualityMeasure131v6._meta, 'version'))
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure131v6.compute_on_change_types
+        result = ClinicalQualityMeasure131v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
@@ -242,7 +242,7 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
         result = tested.compute_results()
         self.assertEqual('due', result.status)
         text = ('Dohav has diabetes and no documentation of retinal '
-                'examination in the past 24 months.')
+                'examination in the past 12 months.')
         self.assertEqual(text, result.narrative)
         self.helper_exam_recommended(result.recommendations)
         self.assertEqual(-1, result.due_in)
@@ -281,11 +281,11 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
                 text = (
                     r'^Dohav has diabetes and a retinal examination was done [\w\s]+ on 2/22/17 '
                     'demonstrating no diabetic eye disease. '
-                    'Next examination is due 1/31/19.$')
+                    'Next examination is due 2/11/18.$')
                 self.assertRegex(result.narrative, text)
                 self.assertEqual([], result.recommendations)
                 self.assertEqual('satisfied', result.status)
-                self.assertEqual(160, result.due_in)
+                self.assertEqual(-194, result.due_in)
             else:
                 text = (
                     r'^Dohav has diabetes and a prior abnormal retinal examination [\w\s]+ '
@@ -315,7 +315,7 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
                 tested = ClinicalQualityMeasure131v6(patient=patient, timeframe=timeframe, now=now)
                 result = tested.compute_results()
                 text = ('Dohav has diabetes and no documentation of retinal '
-                        'examination in the past 24 months.')
+                        'examination in the past 12 months.')
                 self.assertEqual(text, result.narrative)
                 self.helper_exam_recommended(result.recommendations)
                 self.assertEqual('due', result.status)
@@ -399,11 +399,11 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
             if code == '721103006':
                 text = ('Dohav has diabetes and a retinal examination was done 8 months ago '
                         'on 8/5/18 demonstrating no diabetic eye disease. '
-                        'Next examination is due 7/31/19.')
+                        'Next examination is due 2/1/19.')
                 self.assertEqual(text, result.narrative)
                 self.assertEqual([], result.recommendations)
                 self.assertEqual('satisfied', result.status)
-                self.assertEqual(120, result.due_in)
+                self.assertEqual(-60, result.due_in)
             else:
                 text = ('Dohav has diabetes and a prior abnormal retinal examination 8 months ago '
                         'on 8/5/18 showing Retinopathy co-occurrent and due to diabetes mellitus. '
