@@ -28,17 +28,17 @@ class ClinicalQualityMeasure134v6Test(SDKBaseTest):
         expected = (
             'Patients 18-75 years of age with diabetes who have not had a nephropathy screening '
             'test in the last year or evidence of nephropathy.')
-        self.assertEqual(expected, ClinicalQualityMeasure134v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure134v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms134v6'
-        self.assertEqual(expected, ClinicalQualityMeasure134v6.information)
+        self.assertEqual(expected, ClinicalQualityMeasure134v6._meta.information)
 
-    def test_revision(self):
-        self.assertEqual('2019-02-12v1', ClinicalQualityMeasure134v6.revision())
+    def test_version(self):
+        self.assertTrue(hasattr(ClinicalQualityMeasure134v6._meta, 'version'))
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure134v6.compute_on_change_types
+        result = ClinicalQualityMeasure134v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
