@@ -33,17 +33,14 @@ class TestClinicalQualityMeasure138v6(SDKBaseTest):
             'Patients aged 18 years and older who have not been screened for tobacco use OR '
             'who have not received tobacco cessation intervention if identified as a tobacco user.'
         )
-        self.assertEqual(expected, ClinicalQualityMeasure138v6.description)
+        self.assertEqual(expected, ClinicalQualityMeasure138v6._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
-        self.assertEqual(expected, ClinicalQualityMeasure138v6.information)
-
-    def test_revision(self):
-        self.assertEqual('2019-04-03v1', ClinicalQualityMeasure138v6.revision())
+        self.assertEqual(expected, ClinicalQualityMeasure138v6._meta.information)
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure138v6.compute_on_change_types
+        result = ClinicalQualityMeasure138v6._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'billing_line_item',
