@@ -25,17 +25,14 @@ class TestClinicalQualityMeasure138v6p1(SDKBaseTest):
     def test_description(self):
         expected = ('Patients aged 18 years and older who have not been '
                     'screened for tobacco use in the last year.')
-        self.assertEqual(expected, ClinicalQualityMeasure138v6p1.description)
+        self.assertEqual(expected, ClinicalQualityMeasure138v6p1._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
-        self.assertEqual(expected, ClinicalQualityMeasure138v6p1.information)
-
-    def test_revision(self):
-        self.assertEqual('2019-04-18v1', ClinicalQualityMeasure138v6p1.revision())
+        self.assertEqual(expected, ClinicalQualityMeasure138v6p1._meta.information)
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure138v6p1.compute_on_change_types
+        result = ClinicalQualityMeasure138v6p1._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'billing_line_item',
