@@ -28,17 +28,14 @@ class TestClinicalQualityMeasure138v6p2(SDKBaseTest):
         expected = ('Patients aged 18 years and older, and identified as a tobacco user, '
                     'who have not received tobacco cessation intervention such as counselling, '
                     'referral or medication.')
-        self.assertEqual(expected, ClinicalQualityMeasure138v6p2.description)
+        self.assertEqual(expected, ClinicalQualityMeasure138v6p2._meta.description)
 
     def test_information(self):
         expected = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
-        self.assertEqual(expected, ClinicalQualityMeasure138v6p2.information)
-
-    def test_revision(self):
-        self.assertEqual('2019-04-18v1', ClinicalQualityMeasure138v6p2.revision())
+        self.assertEqual(expected, ClinicalQualityMeasure138v6p2._meta.information)
 
     def test_change_types(self):
-        result = ClinicalQualityMeasure138v6p2.compute_on_change_types
+        result = ClinicalQualityMeasure138v6p2._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'billing_line_item',
