@@ -2,9 +2,9 @@
 
 import json
 
-from os.path import basename, join
+from os.path import join
 from pathlib import Path
-from typing import Any, cast, Dict, List, Optional, TypedDict, Union
+from typing import Any, Dict, List, Optional, TypedDict, Union
 
 from datetime import date
 
@@ -12,12 +12,14 @@ import arrow
 import click
 import requests
 
+from canvas_workflow_kit import settings
+from canvas_workflow_kit.api import fetch_patient
 from canvas_workflow_kit.patient import Patient
 from canvas_workflow_kit.timeframe import Timeframe
-from canvas_workflow_kit.utils import parse_class_from_python_source
-
-from stringcase import camelcase
-from decouple import Config, RepositoryIni
+from canvas_workflow_kit.internal.string import snakecase
+from canvas_workflow_kit.utils import (
+    parse_class_from_python_source, load_local_patient
+)
 
 mocks_path = 'TODO'
 
@@ -44,115 +46,6 @@ def red(string: str) -> str:
     return click.style(string, fg='red')
 
 
-def get_settings_path() -> Path:
-    return Path.home() / '.canvas' / 'config.ini'
-
-# Settings ---------------
-#
-
-
-def read_settings(ctx) -> Dict[str, Any]:
-
-    try:
-        ini = RepositoryIni(get_settings_path())
-    except FileNotFoundError:
-        raise click.ClickException(
-            f'Please add your configuration at "{get_settings_path()}"; you can set '
-            'defaults using `canvas-cli create-default-settings`.')
-
-    if not ini.parser.has_section(ctx.obj['config_section']):
-        raise click.ClickException(
-            f'Settings file "{get_settings_path()}" does not contain section "{ctx.obj["config_section"]}"; '
-            'you can set defaults using `canvas-cli create-default-settings`.')
-
-    ini.SECTION = ctx.obj['config_section']
-    config = Config(ini)
-
-    settings: Dict[str, Any] = {
-        'url': config('url', cast=str),
-        'api_key': config('api-key', cast=str)
-    }
-
-    return settings
-
-
-class PatientData(TypedDict):
-    billingLineItems: List
-    conditions: List
-    imagingReports: List
-    immunizations: List
-    instructions: List
-    interviews: List
-    labReports: List
-    medications: List
-    referralReports: List
-    vitalSigns: List
-    patient: Dict[str, Any]
-    protocolOverrides: List
-    changeTypes: List
-    protocols: List
-
-
-def load_patient(fixture_folder: Path) -> Patient:
-    data: PatientData = {
-        'billingLineItems': [],
-        'conditions': [],
-        'imagingReports': [],
-        'immunizations': [],
-        'instructions': [],
-        'interviews': [],
-        'labReports': [],
-        'medications': [],
-        'referralReports': [],
-        'referrals': [],
-        'vitalSigns': [],
-        'patient': {},
-        'protocolOverrides': [],
-        'changeTypes': [],
-        'protocols': [],
-    }
-
-    file_loaded = False
-
-    for filepath in fixture_folder.glob('*.json'):
-        file_loaded = True
-
-        filename = str(basename(filepath))
-        field = camelcase(filename.split('.')[0])
-
-        with open(filepath, 'r') as file:
-            # if field not in data:
-            #     raise click.ClickException(
-            #         f'Found file that does not match a known field: "{field}"')
-
-            data[field] = json.load(file)  # type: ignore
-
-    if not file_loaded:
-        raise click.ClickException(f'No JSON files were found in "{fixture_folder}"')
-
-    data['patient']['key'] = fixture_folder.name
-
-    # click.echo(json.dumps(data, indent=2))
-
-    return Patient(data)
-
-
-# def load_patient_data(patient_key: str, field: str) -> List:
-#     """
-#     Load data from mock data JSON files dumped by the dump_patient command.
-#     """
-#     filename = f'{mocks_path}/{patient_key}/{field}.json'
-
-#     if not exists(filename):
-#         if field == 'patient':
-#             raise Exception(f'Missing mock patient data for "{patient_key}"!')
-
-#         return []
-
-#     with open(filename, 'r') as file:
-#         return json.load(file)  # type: ignore
-
-
 # CLI Commands -----------------------------------
 
 @click.group()
@@ -161,10 +54,13 @@ def load_patient(fixture_folder: Path) -> Patient:
 def cli(ctx, use_config='canvas_cli'):
 
     ctx.ensure_object(dict)
-    ctx.obj['config_section'] = use_config and use_config or 'canvas_cli'
+    ctx.obj['config_section'] = use_config and use_config or settings.DEFAULT_CONFIG_SECTION
 
     if ctx.invoked_subcommand != 'create-default-settings':
-        ctx.obj['settings'] = read_settings(ctx)
+        try:
+            ctx.obj['settings'] = settings.read_config(ctx.obj['config_section'])
+        except (FileNotFoundError, ValueError) as e:
+            raise click.ClickException(e)
 
 
 @cli.command()
@@ -174,7 +70,7 @@ def create_default_settings():
     File will only be created if it does not yet exist.
     """
 
-    settings_path = get_settings_path()
+    settings_path = settings.CONFIG_PATH
 
     if settings_path.is_file():
         raise click.ClickException(f'Settings file already exists at {settings_path}')
@@ -239,11 +135,7 @@ def fixture_from_patient(ctx, patient_keys: List[str], destination: Path):
 def _process_fixture_from_patient(ctx, patient_key, output_directory):
     click.echo(f'Getting fixture from patient "{patient_key}"...')
 
-    response = requests.get(join(
-        ctx.obj["settings"]["url"], f'api/PatientProtocolInput/{patient_key}'
-    ), headers={'Authorization': ctx.obj['settings']['api_key']})
-    response.raise_for_status()
-    response_json = response.json()
+    response_json = fetch_patient(patient_key, ctx.obj['config_section'])
 
     if not output_directory:
         output_directory = Path(".")
@@ -255,7 +147,7 @@ def _process_fixture_from_patient(ctx, patient_key, output_directory):
 
     output_directory.mkdir(parents=True, exist_ok=True)
     for key, values in response_json.items():
-        (output_directory / f'{key}.json').write_text(json.dumps(values))
+        (output_directory / f'{snakecase(key)}.json').write_text(json.dumps(values))
 
     click.echo(green(f'Successfully wrote patient fixture to {output_directory.absolute()}'))
 
@@ -307,7 +199,7 @@ def test_fixture_directory(
 
     click.echo(fixture_title)
 
-    patient = load_patient(Path(fixture_folder))
+    patient = load_local_patient(Path(fixture_folder))
 
     if date:
         date = arrow.get(date)
