@@ -71,6 +71,9 @@ class CHANGE_TYPE:
     MEDICATION = 'medication'
     "Recompute protocol when a medication has been updated."
 
+    MESSAGE = 'message'
+    "Recompute protocol when a patient message transmission has been created."
+
     PATIENT = 'patient'
     "Recompute protocol when a patient's demographic information has been updated."
 
