@@ -628,7 +628,7 @@ class InpatientStayRecordSet(PatientEventRecordSet):
         'cpt',
     ]
     DATE_FIELD = 'noteTimestamp'
-    PATIENT_FIELD = 'inpatientStay'
+    PATIENT_FIELD = 'inpatient_stays'
     API_UPDATE_FIELD = 'inpatientStay'
 
 
@@ -693,3 +693,22 @@ class ProtocolOverrideRecordSet(PatientRecordSet):
                 'system': system,
             }]
         return []
+
+
+class UpcomingAppointmentRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'upcoming_appointments'
+    API_UPDATE_FIELD = 'upcomingAppointments'
+    DATE_FIELD = 'startTime'
+
+
+class UpcomingAppointmentNoteRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'upcoming_appointment_notes'
+    API_UPDATE_FIELD = 'upcomingAppointmentNotes'
+
+
+class MessageRecordSet(PatientRecordSet):
+    VALID_SYSTEMS: List[str] = ['canvas', 'internal']
+    PATIENT_FIELD = 'messages'
+    API_UPDATE_FIELD = 'messages'
