@@ -36,11 +36,21 @@ from canvas_workflow_kit import settings
 from memoization import cached
 from requests.auth import HTTPDigestAuth
 
+from functools import singledispatchmethod
+
 from . import events
 from .constants import CHANGE_TYPE
-from .metaclass import AttrDict, DeclarativeFieldsMetaclass
+from .internal.attrdict import AttrDict
+from .internal.string import snakecase
+from .metaclass import DeclarativeFieldsMetaclass
 from .patient import Patient
-from .recommendation import Recommendation, TaskRecommendation
+from .recommendation import (
+    Recommendation, LabRecommendation, PlanRecommendation,
+    TaskRecommendation, ReferRecommendation, ImagingRecommendation,
+    PerformRecommendation, HyperlinkRecommendation, InterviewRecommendation,
+    PrescribeRecommendation, VitalSignRecommendation, InstructionRecommendation,
+    ImmunizationRecommendation, StructuredAssessmentRecommendation
+)
 from .timeframe import Timeframe
 
 STATUS_DUE = 'due'
@@ -114,6 +124,26 @@ def get_external_protocols(protocol_patient):
     return response_json['protocols']
 
 
+RECOMMENDATION_CLASSES = (
+    LabRecommendation, PlanRecommendation,
+    TaskRecommendation, ReferRecommendation, ImagingRecommendation,
+    PerformRecommendation, HyperlinkRecommendation, InterviewRecommendation,
+    PrescribeRecommendation, VitalSignRecommendation, InstructionRecommendation,
+    ImmunizationRecommendation, StructuredAssessmentRecommendation
+)
+
+
+def add_recommendation_factory(recommendation_class):
+    """
+    Generate generic add_*_recommendation methods.
+    Eg: add_lab_recommendation(*args, **kwargs)
+    """
+    def add_recommendation_class(result, *args, **kwargs):
+        recommendation = recommendation_class(*args, **kwargs)
+        result.recommendations.append(recommendation)
+    return add_recommendation_class
+
+
 class ProtocolResult:
     recommendations: List[Recommendation]
     status: str
@@ -130,7 +160,28 @@ class ProtocolResult:
         self.days_of_notice = 30
         self.next_review = None
 
-    def add_recommendation(self, recommendation: Recommendation):
+        # Create add_*_recommendation methods
+        for recommendation_class in RECOMMENDATION_CLASSES:
+            dynamic_class = add_recommendation_factory(recommendation_class)
+            snake_case_type = snakecase(recommendation_class.__name__)
+            setattr(self.__class__, f'add_{snake_case_type}', dynamic_class)
+
+    @singledispatchmethod
+    def add_recommendation(self, *args, **kwargs):
+        """
+        Add a recommendation to the recommendations list.
+        """
+        print("standard recwith args", *args)
+        recommendation = Recommendation(*args, **kwargs)
+        self.recommendations.append(recommendation)
+
+    @add_recommendation.register
+    def _(self, recommendation: Recommendation):
+        """
+        Add a Recommendation class to the recommendations list.
+        Deprecated: use add_recommendation(*args) instead.
+        """
+        print("added rec", recommendation)
         self.recommendations.append(recommendation)
 
     def add_narrative(self, narrative: str):
@@ -163,8 +214,11 @@ class Protocol(metaclass=DeclarativeFieldsMetaclass):
         self.patient = patient
 
     @property
-    def identifier(self):
-        return self.identifiers[0]
+    def identifier(self) -> str:
+        identifiers = self._meta.identifiers
+        if len(identifiers):
+            return identifiers[0]
+        return ""
 
     @classmethod
     def protocol_key(cls) -> str:
@@ -222,15 +276,6 @@ class Protocol(metaclass=DeclarativeFieldsMetaclass):
         return True
 
 
-class NotificationProtocol(Protocol):
-    """
-    A protocol that sends a payload to an endpoint
-    """
-
-    def __init__(self, patient: Patient, change_types: List = None, **kwargs):
-        super().__init__(patient=patient, **kwargs)
-
-
 class ClinicalQualityMeasure(Protocol):
 
     # The data sources that will invalidate this CQM; e.g. if this CQM uses interviews then if a
@@ -270,6 +315,7 @@ class ClinicalQualityMeasure(Protocol):
 
         self.context = context if context == CONTEXT_GUIDANCE else CONTEXT_REPORT
         self._results: Optional[ProtocolResult] = None
+        self.canvas_updates = []
 
         if not self.impacted_by_changes(change_types):
             self._results = ProtocolResult()
@@ -299,10 +345,10 @@ class ClinicalQualityMeasure(Protocol):
         # TODO: See if the calling process can select and compute only the protocols
         # that match change-types, instead of instantiating in order to check.
         # Will help reduce code, and speed things up.
-        if not change_types or not self.compute_on_change_types:
+        if not change_types or not self._meta.compute_on_change_types:
             return True
 
-        for change in self.compute_on_change_types:
+        for change in self._meta.compute_on_change_types:
             if change in change_types:
                 return True
 
@@ -364,9 +410,15 @@ class ClinicalQualityMeasure(Protocol):
 
         return self._results
 
-    def set_context(self, context: object = {}) -> None:
+    def set_context(self, context: Dict = {}) -> None:
         self.context = AttrDict(context)
 
+    def set_updates(self, canvas_updates: List[Dict]) -> None:
+        self.canvas_updates = canvas_updates
+
+    def updates(self) -> List[Dict]:
+        return self.canvas_updates
+
     def recommendations(self) -> List[Recommendation]:
         return self.results().recommendations
 
@@ -397,14 +449,15 @@ class ClinicalQualityMeasure(Protocol):
         return 'between %s and %s' % (day_from.format('M/D/YY'), day_to.format('M/D/YY'))
 
     def screening_interval_context(self) -> str:
-        if hasattr(self._meta, 'default_display_interval_in_days'):
+        try:
             abc = self.friendly_time_duration(self._meta.default_display_interval_in_days)
-            if self.period_adjustment:
-                abc = self.friendly_time_duration(self.period_adjustment['cycleDays'])
-            return f'Current screening interval {abc}.'
-        else:
+        except (AttributeError, KeyError):
             return ''
 
+        if self.period_adjustment:
+            abc = self.friendly_time_duration(self.period_adjustment['cycleDays'])
+        return f'Current screening interval {abc}.'
+
     @staticmethod
     def friendly_time_duration(duration_in_days: int) -> str:
         friendly_duration = 'invalid duration'
@@ -583,7 +636,7 @@ def get_protocols(module) -> Dict[str, List[Type[Protocol]]]:
         if not subclass.enabled():
             continue
 
-        for event_type in subclass.responds_to_event_types:
+        for event_type in subclass._meta.responds_to_event_types:
             protocols_by_event_type[event_type].append(subclass)
 
     return protocols_by_event_type
