@@ -12,14 +12,13 @@ def compute_results(self) -> ProtocolResult:
         title = ('Consider updating the Diabetes without complications (E11.9) '
                  'to Diabetes with secondary eye disease as clinically appropriate.')
         result.add_narrative(comment)
-        result.add_recommendation(
-            Recommendation(
-                key='HCC003v1_RECOMMEND_DIAGNOSE_EYE',
-                rank=1,
-                button='Diagnose',
-                title=title,
-                narrative=f'{self.patient.first_name} has Diabetes without complications,
-                command={'key': 'diagnose'}))
+        result.add_diagnose_recommendation(
+            key='HCC003v1_RECOMMEND_DIAGNOSE_EYE',
+            rank=1,
+            button='Diagnose',
+            title=title,
+            narrative=f'{self.patient.first_name} has Diabetes without complications,
+            command={'key': 'diagnose'})
 
 """
 
