@@ -19,6 +19,8 @@ from canvas_workflow_kit.timeframe import Timeframe
 from .base import SDKBaseTest
 
 
+LOADED_PROTOCOLS = get_protocols(get_protocols_unittest)
+
 class TestProtocolResult(SDKBaseTest):
 
     def test___init__(self):
@@ -41,6 +43,27 @@ class TestProtocolResult(SDKBaseTest):
         for recommendation in tested.recommendations:
             self.assertIn(recommendation.title, ['reco A', 'reco B'])
 
+    def test_add_recommendation_shorthand(self):
+        tested = ProtocolResult()
+        self.assertEqual([], tested.recommendations)
+        tested.add_recommendation(
+            'KEY-A', 7, 'ACT', 'reco A', 'this is the reco A')
+        tested.add_recommendation(
+            'KEY-B', 3, 'BAC', 'reco B', 'this is the reco B')
+        self.assertEqual(2, len(tested.recommendations))
+        for recommendation in tested.recommendations:
+            self.assertIn(recommendation.title, ['reco A', 'reco B'])
+
+    def test_add_recommendation_shorthand_custom(self):
+        tested = ProtocolResult()
+        self.assertEqual([], tested.recommendations)
+        tested.add_plan_recommendation('KEY-A', 7, 'ACT', 'reco A', 'this is the reco A')
+        tested.add_vital_sign_recommendation('KEY-B', 3, 'BAC', 'reco B', 'this is the reco B')
+        self.assertEqual(2, len(tested.recommendations))
+
+        self.assertEqual(tested.recommendations[0].__class__.__name__, 'PlanRecommendation')
+        self.assertEqual(tested.recommendations[1].__class__.__name__, 'VitalSignRecommendation')
+
     def test_add_narrative(self):
         tested = ProtocolResult()
         self.assertEqual([], tested.narratives)
@@ -75,12 +98,12 @@ class TestProtocol(SDKBaseTest):
         tested = Protocol(patient)
         self.assertIsInstance(tested, Protocol)
         self.assertIs(patient, tested.patient)
-        self.assertEqual([], tested.compute_on_change_types)
-        self.assertEqual([], tested.responds_to_event_types)
-        self.assertEqual([], tested.identifiers)
-        self.assertEqual('', tested.title)
-        self.assertEqual('', tested.description)
-        self.assertEqual('', tested.information)
+        self.assertEqual([], tested._meta.compute_on_change_types)
+        self.assertEqual([], tested._meta.responds_to_event_types)
+        self.assertEqual([], tested._meta.identifiers)
+        self.assertEqual('', tested._meta.title)
+        self.assertEqual('', tested._meta.description)
+        self.assertEqual('', tested._meta.information)
 
     def test_protocol_key(self):
         patient = self.load_patient('full')
@@ -98,19 +121,17 @@ class TestProtocol(SDKBaseTest):
         patient = self.load_patient('full')
         tested = Protocol(patient)
         expected = ''
-        result = tested.protocol_title()
+        result = tested._meta.title
         self.assertEqual(expected, result)
 
         tested = TestProto(patient)
         expected = 'Title TestProtocol'
-        result = tested.protocol_title()
+        result = tested._meta.title
         self.assertEqual(expected, result)
 
     def test_references(self):
         patient = self.load_patient('full')
         tested = Protocol(patient)
-        with self.assertRaises(NotImplementedError):
-            tested.references
 
         tested = TestProto(patient)
         expected = [
@@ -120,7 +141,7 @@ class TestProtocol(SDKBaseTest):
             'Small title #4. WWW.unittests.med/canvas?id=4',
             'Not valid #5  www.unittests.med/canvas?id=5 because of this',
         ]
-        self.assertEqual(expected, tested.references)
+        self.assertEqual(expected, tested._meta.references)
 
     def test_relative_float(self):
         tests = [
@@ -251,7 +272,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         # no change types, time frame provided
         tested = CQMImplementation(patient=patient)
 
-        self.assertEqual(['HEALTH_MAINTENANCE'], tested.responds_to_event_types)
+        self.assertEqual(['HEALTH_MAINTENANCE'], tested._meta.responds_to_event_types)
         self.assertIsNone(tested.results())
 
         result = tested.timeframe
@@ -259,16 +280,17 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         fmt = '%Y-%m-%d %H:%M'
 
         last_year = {
-            'year': datetime.today().year - 1,
-            'month': datetime.today().month,
-            'day': datetime.today().day,
-            'hour': datetime.today().hour,
-            'minute': datetime.today().minute,
+            'year': datetime.utcnow().year - 1,
+            'month': datetime.utcnow().month,
+            'day': datetime.utcnow().day,
+            'hour': datetime.utcnow().hour,
+            'minute': datetime.utcnow().minute,
         }
-        self.assertEqual(datetime(**last_year).strftime(fmt), tested.timeframe.start.strftime(fmt))
-        self.assertEqual(datetime.today().strftime(fmt), tested.timeframe.end.strftime(fmt))
 
-        self.assertEqual(datetime.today().strftime(fmt), tested.now.strftime(fmt))
+        self.assertEqual(datetime(**last_year).strftime(fmt), tested.timeframe.start.strftime(fmt))
+        self.assertEqual(datetime.utcnow().strftime(fmt), tested.timeframe.end.strftime(fmt))
+
+        self.assertEqual(datetime.utcnow().strftime(fmt), tested.now.strftime(fmt))
         self.assertEqual('report', tested.context)
 
         # context provided
@@ -291,7 +313,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         self.assertIs(start, result.start)
         self.assertIs(end, result.end)
 
-        self.assertEqual(datetime.today().strftime(fmt), tested.now.strftime(fmt))
+        self.assertEqual(datetime.utcnow().strftime(fmt), tested.now.strftime(fmt))
 
         # now provided
         tested = ClinicalQualityMeasure(patient=patient, now=arrow.get('2018-10-30 12:34'))
@@ -316,7 +338,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         # + empty -> instance is computable
         tested = CQMImplementation(patient=patient, change_types=[])
 
-        self.assertEqual(['HEALTH_MAINTENANCE'], tested.responds_to_event_types)
+        self.assertEqual(['HEALTH_MAINTENANCE'], tested._meta.responds_to_event_types)
         self.assertIsNone(tested.results())
 
         # + with changes + instance with empty impacting list -> instance is computable
@@ -326,15 +348,16 @@ class TestClinicalQualityMeasure(SDKBaseTest):
                 'change_B',
             ])
 
-        self.assertEqual(['HEALTH_MAINTENANCE'], tested.responds_to_event_types)
+        self.assertEqual(['HEALTH_MAINTENANCE'], tested._meta.responds_to_event_types)
         self.assertIsNone(tested.results())
 
         # + with changes + instance impacted by one change -> instance is computable
         class UnitTestCQMImpactedByA(CQMImplementation):
-            compute_on_change_types = [
-                'change_A',
-                'change_C',
-            ]
+            class Meta:
+                compute_on_change_types = [
+                    'change_A',
+                    'change_C',
+                ]
 
         tested = UnitTestCQMImpactedByA(
             patient=patient, change_types=[
@@ -342,7 +365,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
                 'change_B',
             ])
 
-        self.assertEqual(['HEALTH_MAINTENANCE'], tested.responds_to_event_types)
+        self.assertEqual(['HEALTH_MAINTENANCE'], tested._meta.responds_to_event_types)
         self.assertIsNone(tested.results())
 
         # + with changes + instance impacted by other changes -> instance is not computable
@@ -352,7 +375,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
                 'change_B',
             ])
 
-        self.assertEqual(['HEALTH_MAINTENANCE'], tested.responds_to_event_types)
+        self.assertEqual(['HEALTH_MAINTENANCE'], tested._meta.responds_to_event_types)
         self.assertIsNotNone(tested.results())
         self.assertEqual('not_relevant', tested.status())
 
@@ -371,7 +394,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         ])
         self.assertTrue(result)
         # change types + impacting changes in the changes -> True
-        tested.compute_on_change_types = [
+        tested._meta.compute_on_change_types = [
             'change_X',
             'change_B',
             'change_C',
@@ -587,10 +610,10 @@ class TestClinicalQualityMeasure(SDKBaseTest):
 
         tests = [
             ('2018-09-09', '3 weeks ago on 9/9/18'),
-            ('2018-09-19', '2 weeks ago on 9/19/18'),
+            ('2018-09-19', 'a week ago on 9/19/18'),
             ('2018-07-13', '3 months ago on 7/13/18'),
             ('2018-03-13', '7 months ago on 3/13/18'),
-            ('2017-03-13', '2 years ago on 3/13/17'),
+            ('2017-03-13', 'a year ago on 3/13/17'),
         ]
         for day, expected in tests:
             result = tested.display_date(arrow.get(day))
@@ -613,7 +636,8 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         self.assertEqual(result, '')
 
         class CQMWithDefaultDisplayInterval(ClinicalQualityMeasure):
-            default_display_interval_in_days = 30
+            class Meta:
+                default_display_interval_in_days = 30
 
         # no period adjustment
         cqm = CQMWithDefaultDisplayInterval(patient=patient)
@@ -621,7 +645,7 @@ class TestClinicalQualityMeasure(SDKBaseTest):
         self.assertEqual(result, 'Current screening interval 1 month.')
         # there is a period adjustment
         cqm = CQMWithDefaultDisplayInterval(patient=patient)
-        cqm.default_display_interval_in_days = 30
+        cqm._meta.default_display_interval_in_days = 30
         cqm.period_adjustment = {'cycleDays': 60}
         result = cqm.screening_interval_context()
         self.assertEqual(result, 'Current screening interval 2 months.')
@@ -656,7 +680,7 @@ class TestProcedures(SDKBaseTest):
 
     def test_get_protocols(self):
         # result includes also the actual classes
-        result = get_protocols(get_protocols_unittest)
+        result = LOADED_PROTOCOLS
         self.assertEqual(2, len(result))
         self.assertIn('HEALTH_MAINTENANCE', result)
         health = list(map(lambda x: x.__name__, result['HEALTH_MAINTENANCE']))
@@ -677,8 +701,8 @@ class TestProcedures(SDKBaseTest):
 
     def test_protocols_for_patient(self):
         patient = self.load_patient('full')
-        protocols = get_protocols(get_protocols_unittest)
-        result = protocols_for_patient(protocols, 'UNIT_TESTS', patient)
+        protocols = LOADED_PROTOCOLS
+        result = protocols_for_patient(protocols['UNIT_TESTS'], patient)
         expected = [
             'ProtoUnitTestAllTrue',
             'ProtoUnitTestX',
@@ -692,7 +716,7 @@ class TestProcedures(SDKBaseTest):
             self.assertIn(instance.__class__.__name__, expected)
             self.assertEqual('report', instance.context)
 
-        result = protocols_for_patient(protocols, 'UNIT_TESTS', patient, context='guidance')
+        result = protocols_for_patient(protocols['UNIT_TESTS'], patient, context='guidance')
         expected = [
             'ProtoUnitTestAllTrue',
             'ProtoUnitTestX',
@@ -707,7 +731,7 @@ class TestProcedures(SDKBaseTest):
             self.assertEqual('guidance', instance.context)
 
         # no empty change types
-        result = protocols_for_patient(protocols, 'UNIT_TESTS', patient, [
+        result = protocols_for_patient(protocols['UNIT_TESTS'], patient, [
             'change_A',
             'change_B',
         ])
@@ -740,8 +764,8 @@ class TestProcedures(SDKBaseTest):
             'modified': '2018-10-02T21:50:09.661490Z'
         }])
 
-        protocols = get_protocols(get_protocols_unittest)
-        result = protocols_for_patient(protocols, 'UNIT_TESTS', patient)
+        protocols = LOADED_PROTOCOLS
+        result = protocols_for_patient(protocols['UNIT_TESTS'], patient)
         expected = [
             'ProtoUnitTestAllTrue',
             'ProtoUnitTestX',
@@ -767,15 +791,17 @@ class TestProto(Protocol):
 
     the_status = 'current status'
 
-    references = [
-        'Small title #1. www.unittests.med/canvas?id=1',
-        'Small title #2. http://www.unittests.med/canvas?id=2',
-        'Small title #3. https://www.unittests.med/canvas?id=3',
-        'Small title #4. WWW.unittests.med/canvas?id=4',
-        'Not valid #5  www.unittests.med/canvas?id=5 because of this',
-    ]
+    class Meta:
 
-    title = 'Title TestProtocol'
+        title = 'Title TestProtocol'
+
+        references = [
+            'Small title #1. www.unittests.med/canvas?id=1',
+            'Small title #2. http://www.unittests.med/canvas?id=2',
+            'Small title #3. https://www.unittests.med/canvas?id=3',
+            'Small title #4. WWW.unittests.med/canvas?id=4',
+            'Not valid #5  www.unittests.med/canvas?id=5 because of this',
+        ]
 
     def status(self) -> str:
         return self.the_status
@@ -797,11 +823,12 @@ class TestPFalse(Protocol):
 
 class CQMImplementation(ClinicalQualityMeasure):
 
-    references = []
-
-    @classmethod
-    def revision(cls) -> str:
-        return ''
+    class Meta:
+        compute_on_change_types = [
+            'change_A',
+            'change_B',
+            'change_C',
+        ]
 
     def in_initial_population(self) -> bool:
         pass
